@@ -7,7 +7,6 @@ import (
 	"github.com/RHsyseng/operator-utils/pkg/validation"
 	"github.com/ghodss/yaml"
 	"github.com/gobuffalo/packr/v2"
-	v1 "github.com/kiegroup/kie-cloud-operator/pkg/apis/app/v1"
 	api "github.com/kiegroup/kie-cloud-operator/pkg/apis/app/v2"
 	"github.com/kiegroup/kie-cloud-operator/pkg/controller/kieapp/constants"
 	"github.com/stretchr/testify/assert"
@@ -16,18 +15,8 @@ import (
 )
 
 func TestExampleCustomResources(t *testing.T) {
-	schema := getSchema(t, v1.SchemeGroupVersion.Version)
-	box := packr.New("deploy/crs/v1", "../../../../deploy/crs/v1")
-	assert.Greater(t, len(box.List()), 0)
-	for _, file := range box.List() {
-		yamlString, err := box.FindString(file)
-		assert.NoError(t, err, "Error reading %v CR yaml", file)
-		var input map[string]interface{}
-		assert.NoError(t, yaml.Unmarshal([]byte(yamlString), &input))
-		assert.NoError(t, schema.Validate(input), "File %v does not validate against the CRD schema", file)
-	}
-	schema = getSchema(t, api.SchemeGroupVersion.Version)
-	box = packr.New("deploy/crs/v2", "../../../../deploy/crs/v2")
+	schema := getSchema(t, api.SchemeGroupVersion.Version)
+	box := packr.New("deploy/crs/v2", "../../../../deploy/crs/v2")
 	assert.Greater(t, len(box.List()), 0)
 	for _, file := range box.List() {
 		yamlString, err := box.FindString(file)
@@ -118,20 +107,10 @@ func TestCompleteCRD(t *testing.T) {
 	schema := getSchema(t, api.SchemeGroupVersion.Version)
 	missingEntries := schema.GetMissingEntries(&api.KieApp{})
 	for _, missing := range missingEntries {
-		if strings.HasPrefix(missing.Path, "/status") {
-			//Not using subresources, so status is not expected to appear in CRD
+		if strings.HasPrefix(missing.Path, "/status/conditions/lastTransitionTime") {
+			// ...
 		} else if strings.Contains(missing.Path, "/env/valueFrom/") {
 			//The valueFrom is not expected to be used and is not fully defined TODO: verify
-		} else if strings.HasSuffix(missing.Path, "/from/uid") {
-			//The ObjectReference in From is not expected to be used and is not fully defined TODO: verify
-		} else if strings.HasSuffix(missing.Path, "/from/namespace") {
-			//The ObjectReference in From is not expected to be used and is not fully defined TODO: verify
-		} else if strings.HasSuffix(missing.Path, "/from/apiVersion") {
-			//The ObjectReference in From is not expected to be used and is not fully defined TODO: verify
-		} else if strings.HasSuffix(missing.Path, "/from/resourceVersion") {
-			//The ObjectReference in From is not expected to be used and is not fully defined TODO: verify
-		} else if strings.HasSuffix(missing.Path, "/from/fieldPath") {
-			//The ObjectReference in From is not expected to be used and is not fully defined TODO: verify
 		} else {
 			assert.Fail(t, "Discrepancy between CRD and Struct", "Missing or incorrect schema validation at %v, expected type %v", missing.Path, missing.Type)
 		}
@@ -183,10 +162,10 @@ func snippets(t *testing.T, file, yamlStr string) string {
 }
 
 func TestJvmCrd(t *testing.T) {
-	crdYaml, _ := packr.New("deploy/crds", "../../../../deploy/crds").FindString("kieapp." + api.SchemeGroupVersion.Version + ".crd.yaml")
-	crdJson, _ := yaml.YAMLToJSON([]byte(crdYaml))
+	crdYAML, _ := packr.New("deploy/crds", "../../../../deploy/crds").FindString("kieapp.crd.yaml")
+	crdJSON, _ := yaml.YAMLToJSON([]byte(crdYAML))
 	path := "spec.versions.#(name==" + api.SchemeGroupVersion.Version + ").schema.openAPIV3Schema.properties.spec.properties.objects.properties.servers.items.properties.jvm.properties"
-	jvm := gjson.Get(string(crdJson), path)
+	jvm := gjson.Get(string(crdJSON), path)
 
 	testString(t, "javaOptsAppend", jvm)
 	testInteger(t, "javaMaxMemRatio", jvm)
